@@ -11,7 +11,7 @@ module RD
     include MethodParse
 
     SYSTEM_NAME = "RDtool -- RD2HTMLVisitor"
-    SYSTEM_VERSION = "$Version: 0.6.21$" #"
+    SYSTEM_VERSION = "$Version: "+ RD::VERSION+"$" 
     VERSION = Version.new_from_version_string(SYSTEM_NAME, SYSTEM_VERSION)
 
     def self.version
@@ -78,7 +78,7 @@ module RD
     def document_title
       return @title if @title
       return @filename if @filename
-      return ARGF.filename if ARGF.filename != "-"
+      return @input_filename unless @input_filename == "-"
       "Untitled"
     end
     private :document_title
@@ -104,8 +104,8 @@ module RD
 
     def html_head
       ret = %|<head>\n|
-	ret << html_title + "\n"
-	ret << html_content_type + "\n" if html_content_type
+      ret << html_content_type + "\n" if html_content_type
+      ret << html_title + "\n"
       ret << link_to_css + "\n" if link_to_css
       ret << forward_links + "\n" if forward_links
       ret << backward_links + "\n" if backward_links
