@@ -1,12 +1,11 @@
-require 'runit/testcase'
-require 'runit/cui/mytestrunner'
+require 'test/unit'
 
 require 'rd/list.rb'
 require 'rd/rd-struct'
 
 include RD
 
-class TestList < RUNIT::TestCase
+class TestList < Test::Unit::TestCase
   def setup
     @a = ItemList.new
     @c1 = ItemListItem.new
@@ -52,7 +51,3 @@ class TestList < RUNIT::TestCase
     end
   end
 end
-
-if $0 == __FILE__
-  RUNIT::CUI::MyTestRunner.run(TestList.suite)
-end
