@@ -1,12 +1,11 @@
-require 'runit/testcase'
-require 'runit/cui/testrunner'
+require 'test/unit'
 
 require 'rd/rdfmt'
 require 'rd/element'
 
 include RD
 
-class TestRDTree < RUNIT::TestCase
+class TestRDTree < Test::Unit::TestCase
   def test_s_new
     tr = RDTree.new("=begin\nTEST\n=end\n")
     assert_kind_of(DocumentElement, tr.root)
@@ -16,7 +15,3 @@ class TestRDTree < RUNIT::TestCase
     assert_equal(["test/data"], tr_not_parse.include_paths)
   end
 end
-
-if $0 == __FILE__
-  RUNIT::CUI::TestRunner.run(TestRDTree.suite)
-end
